@@ -53,7 +53,7 @@ class HttpClient(object):
         :param file: Location of file to send.
         :return: The Status code of request and the response text body.
         """
-        response = None
+
         cmd_url = "{endpoint}{cmd}?".format(endpoint=self.endpoint,
                                             cmd=rest_command)
         log.debug("Request is: %s", cmd_url)
@@ -154,6 +154,10 @@ class LoadMaster(HttpClient):
         data = get_data(response)
         virtual_services = []
         services = data.get('VS', [])
+        # if there is no VS key, build_virtual_services will fail with a
+        # ValidationError, which is the best we can do for now
+        # (without changing the upstream code and raising an exception earlier,
+        # possibly retrying)
         if not isinstance(services, list):
             services = [services]
         for service in services:
@@ -173,13 +177,14 @@ class LoadMaster(HttpClient):
             service_id = {"vs": index}
         response = self._get("/showvs", service_id)
         service = get_data(response)
+        # again line below will fail with ValidationError if empty response
         virt_serv = self.build_virtual_service(service)
         return virt_serv
 
     def build_virtual_service(self, service):
         """Create a VirtualService instance with standard defaults"""
         virt_serv = VirtualService(self.access_info,
-                                   service.get('VSAddress', None),
+                                   service.get('VSAddress'),
                                    service.get('VSPort'),
                                    service.get('Protocol'))
         virt_serv.populate_default_attributes(service)
@@ -336,15 +341,15 @@ class LoadMaster(HttpClient):
         response = self._get('/killaslinstance')
         return send_response(response)
 
-    def show_interface(self, interface_id=1):
+    def show_interface(self, interface_id=0):
         if not isinstance(interface_id, int):
             raise ValidationError('"interface_id" must be an integer')
         response = self._get('/showiface', {"interface": interface_id})
         data = get_data(response)
         interface = data["Interface"]
-        address_cidr_split = interface["IPAddress"].split("/")
-        if len(address_cidr_split) > 1:
+        if interface["IPAddress"] is not None:
             # Address/cidr is set in this case and can safely be split
+            address_cidr_split = interface["IPAddress"].split("/")
             interface["IPAddress"] = address_cidr_split[0]
             interface["cidr"] = address_cidr_split[1]
         return interface
@@ -464,7 +469,9 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             }
         response = self._get("/showrs", server_id)
         response_data = get_data(response)
-        server = response_data["Rs"]
+        server = response_data.get("Rs", {})
+        # if there is no Rs key, the following will fail with a ValidationError
+        # which is the best we can do for now
         real_server = self.build_real_server(server)
         return real_server
 
@@ -538,7 +545,7 @@ class RealServer(HttpClient, KempBaseObjectModel):
         if is_successful(response):
             response = self._get("/showrs", self._get_base_parameters())
             data = get_data(response)
-            rs_data = data["Rs"]
+            rs_data = data.get("Rs", {})
             self.populate_default_attributes(rs_data)
         else:
             raise KempTechApiException(get_error_msg(response))
